#!/bin/perl
################################################################################
# Created       : Martin Foster
# Modified      : 10-Aug-2003
################################################################################
#
# Portal - Script part of Ethereal Realms used to embed information about
#          galleries in order to be used as a more formal entrance.
# Copyright (C) 2000-2004  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 29-26503 TWP RD 511
#                 Spruce Grove, Alberta
#                 T7Y 1G4
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use eRealms::Database;						# Database handler
use eRealms::Table;						# Table handler
use eRealms::Template;						# Template handler


################################################################################
# Data Members
################################################################################
my $cgi;							# Common gateway interface handle
my $database;							# Database handle
my $tmpl;							# Template handle

my $scriptname;							# Simply the script name
my $scriptpara;							# Scripted parameters

my %gal;							# Gallery hash

################################################################################
# Program Area
################################################################################

	# Initial handles
	$cgi      = new CGI;
	$database = new eRealms::Database();

	# Connect and fetch
	$database->Connect();

	# Link with hash
	$database->GetHashGallery(\%gal);

	# Initial hash
	$tmpl  = new eRealms::Template(\%gal);

	# Pull script name
	$scriptname = $cgi->url(-relative=>1);

	# Round about way
	if ((length($scriptname) < 2)
	 || ($scriptname =~ /\.(shtml|html)$/i))
	{
		# Assume this is not a real script name
		# Get name and only end
		$scriptname = $0;
		$scriptname =~ s/.*\/(.*)$/$1/gs;
	}


	# Standard listing
	# Image and text
	if (($scriptname =~ /^image/si)
	 or ($scriptname =~ /^text/si))
	{
		# Display appropriate section
		DescriptionHandler($database, $tmpl, \%gal, $scriptname);
	}


################################################################################
# Sub-Routines
################################################################################

#####################
# Description Handler
#
# Exists to provide a fuller front-end to the galleries.   Which would allow for
# spidering and even a nicer interface for people to use when wanting to see what
# is available.

sub DescriptionHandler
{
	#####################
	# Data members
	my $database = shift;					# Database handle
	my $tmpl     = shift;					# Template handle
	my $gal      = shift;					# Gallery hash
	my $option   = shift;					# Scriptname and deicisons

	my $description;					# Query results
	my $genres;						# Query results
	my $statement;						# Query handle

	my %descr;						# Stored descriptions


	#####################
	# Program Area

	# Properly define option
	$option = ($option =~ /^image/si) ? 'image' : 'text';
	


	# Retreive description list
	# Prepare and execute
	$database->Pull(\$statement, "SELECT
		 GenreName        AS \"GenreName\",
		 GenreDescription AS \"GenreDescription\"
		FROM Genre
		WHERE GenreOrder=?", $option);

	# Loop and fetch
	while ($description = $statement->fetchrow_hashref())
	{
		# Simple assignment
		# Ensure names are lower case
		$descr{lc($description->{'GenreName'})} = $description->{'GenreDescription'};
	}

	# Finish up
	$statement->finish();
		


	# Retreive sections list
	# Prepare and execute
	$database->Pull(\$statement, "SELECT
		 GalleryGenre AS \"GalleryGenre\",
		 COUNT(*)     AS \"GalleryCount\"
		FROM Exhibition
		WHERE GalleryType=?
		GROUP BY GalleryGenre
		ORDER BY GalleryGenre", $option);


	# Pre display
	print "<BR>\n";

	# Loop and display
	while ($genres = $statement->fetchrow_hashref())
	{
		# Description
		$description = $descr{lc($genres->{'GalleryGenre'})};
		$description = (defined($description)) ? $description : $gal->{'TxtDescription'}; 

		# Display output
		$tmpl->Show('TmplDescription',
			MCOUNT => $genres->{'GalleryCount'},
			MDESCR => $description,
			MGENRE => $genres->{'GalleryGenre'},
			LGENRE => $gal->{'LnkGallery'} . '/list/' . ucfirst($option) . '/' . $genres->{'GalleryGenre'} . '/'
		 );
	}

	# Finish up
	$statement->finish();
}
